@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.5.2"
+    version = "1.5.6"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -120,8 +120,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
-        payload = f"{payload} > 全部报错: {json.loads(group)} \n\n"
-        payload = f"{payload} > 全部报错: {type(group)} \n\n"
+        payload = f"{payload} > 全部报错: {group} \n\n"
+        payload = f"{payload} > 全部报错: {json.loads(str(group, encoding='utf-8'))} \n\n"
 
         headers = {
             "Content-type": "application/json",
